import 'package:equatable/equatable.dart';
import '../../models/group_balance.dart';

abstract class BalanceState extends Equatable {
  const BalanceState();

  @override
  List<Object?> get props => [];
}

class BalanceInitial extends BalanceState {}

class BalanceLoading extends BalanceState {}

class BalanceLoaded extends BalanceState {
  final GroupBalance groupBalance;

  const BalanceLoaded(this.groupBalance);

  @override
  List<Object?> get props => [groupBalance];
}

class BalanceOperationSuccess extends BalanceState {
  final String message;

  const BalanceOperationSuccess(this.message);

  @override
  List<Object?> get props => [message];
}

class BalanceError extends BalanceState {
  final String message;

  const BalanceError(this.message);

  @override
  List<Object?> get props => [message];
}